.. _set_telescope_pointing:

============================
Telescope Pointing Utilities
============================

.. automodapi:: romancal.orientation.set_telescope_pointing
   :no-inheritance-diagram:

.. automodapi:: romancal.orientation.pointing_summary
   :no-inheritance-diagram:

.. automodapi:: romancal.orientation.v1_calculate
   :no-inheritance-diagram:


Commands
--------

Available commands are as follows. Use the ``-h`` option for more details.

roman_set_telescope_pointing
    Update basic WCS information in Roman exposures from the engineering
    database.

roman_pointing_summary
    Summarize various pointing information in a table.

roman_v1_calculate
    Calculate V1 over a time period.
